__title__ = 'django-i18next'
__version__ = '0.1'
__build__ = 0x000001
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
#__all__ = ('default_app_config',)

default_app_config = 'i18next.apps.Config'
