__title__ = 'i18next.test'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'

import unittest

from i18next.testing.test_core import I18NextCoreTest

if __name__ == '__main__':
    unittest.main()
